@@ -36,11 +36,10 @@
 #include <errno.h>
 #include <X11/Xauth.h>
 
-#include <viciousui.h>
-
 #include "gdm.h"
 #include "gdmcomm.h"
 #include "gdmcommon.h"
+#include "gdmconfig.h"
 
 static pid_t xnest_pid = 0;
 
@@ -91,7 +90,7 @@ get_free_display (void)
 			serv6_addr.sin6_addr =  in6addr_loopback;
 			serv6_addr.sin6_port = htons (6000 + i);
 
-			if (connect (sock, (struct sockaddr *)&serv6_addr, sizeof(serv6_addr)) >= 0 ||  errno != ECONNREFUSED) {
+			if (connect (sock, (struct sockaddr *)&serv6_addr, sizeof (serv6_addr)) >= 0 ||  errno != ECONNREFUSED) {
 				VE_IGNORE_EINTR (close (sock));
 				continue;
 			      }
@@ -266,7 +265,7 @@ make_us_an_exec_vector (const char *xnest)
 	gboolean got_font_path = FALSE;
 	char *font_path = NULL;
 
-	if( ! ve_string_empty (xnest_binary))
+	if ( ! ve_string_empty (xnest_binary))
 		xnest = xnest_binary;
 
 	if (ve_string_empty (xnest))
@@ -469,7 +468,6 @@ main (int argc, char *argv[])
 	const char **args;
 	char *xnest;
 	char **execvec;
-	gchar *config_file, *config_prefix;
 	struct sigaction term;
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
@@ -504,25 +502,14 @@ main (int argc, char *argv[])
 	if (args != NULL && args[0] != NULL)
 		host = args[0];
 
-	config_file = gdm_common_get_config_file ();
-	if (config_file == NULL) {
-		g_print (_("Could not access GDM configuration file.\n"));
-		_exit (1);
-	}
 
-	config_prefix = g_strdup_printf("=%s=/", config_file);
-	gnome_config_push_prefix (config_prefix);
-	xdmcp_enabled = gnome_config_get_bool (GDM_KEY_XDMCP);
-	honor_indirect = gnome_config_get_bool (GDM_KEY_INDIRECT);
-	pidfile = gnome_config_get_string (GDM_KEY_PIDFILE);
-	xnest = gnome_config_get_string (GDM_KEY_XNEST);
-	gnome_config_pop_prefix ();
-	g_free (config_file);
-	g_free (config_prefix);
+	xdmcp_enabled  = gdm_config_get_bool (GDM_KEY_XDMCP);
+	honor_indirect = gdm_config_get_bool (GDM_KEY_INDIRECT);
+	pidfile        = gdm_config_get_string (GDM_KEY_PID_FILE);
+	xnest          = gdm_config_get_string (GDM_KEY_XNEST);
 
 	/* complex and wonderous way to get the exec vector */
 	execvec = make_us_an_exec_vector (xnest);
-	g_free (xnest);
 
 	if (execvec == NULL) {
 		GtkWidget *d;
@@ -587,7 +574,6 @@ main (int argc, char *argv[])
 		pid = 0;
 		if (pidfile != NULL) {
 			VE_IGNORE_EINTR (fp = fopen (pidfile, "r"));
-			g_free (pidfile);
 		}
 		if (fp != NULL) {
 			int r;
