@@ -22,27 +22,24 @@
 #ifndef GDM_COMMON_H
 #define GDM_COMMON_H
 
-#include <vicious.h>
-
 #include "misc.h"
 
 void    gdm_common_show_info_msg        (const gchar *msg_file,
                                          const gchar *msg_font);
-void	gdm_common_message		(const gchar *msg);
+void	gdm_common_message		(const gchar *primary_message, 
+					 const gchar *secondary_message);
 void	gdm_common_abort		(const gchar *format, ...) G_GNUC_PRINTF (1, 2);
 void	gdm_common_setup_cursor		(GdkCursorType type);
-gint	gdm_common_query		(const gchar *msg,
-					 gboolean markup,
+gint	gdm_common_query		(const gchar *primary_message,
+					 const gchar *secondary_message,
+					 const char *posbutton,
+					 const char *negbutton,
+					 gboolean has_cancel);
+gint	gdm_common_warn 		(const gchar *primary_message,
+					 const gchar *secondary_message,
 					 const char *posbutton,
 					 const char *negbutton,
 					 gboolean has_cancel);
-
-gboolean gdm_common_string_same		(VeConfig *config,
-					 const char *cur, const char *key);
-gboolean gdm_common_bool_same		(VeConfig *config,
-					 gboolean cur, const char *key);
-gboolean gdm_common_int_same		(VeConfig *config,
-					 int cur, const char *key);
 
 void    gdm_common_login_sound          (const gchar *GdmSoundProgram,
                                          const gchar *GdmSoundOnLoginReadyFile,
@@ -56,9 +53,8 @@ GdkPixbuf *gdm_common_get_face          (const char *filename,
                                          guint       max_width,
                                          guint       max_height);
 gchar*	gdm_common_get_config_file	(void);
-
-gboolean gdm_common_select_time_format	(VeConfig *config);
-
-void setup_background_color (gchar *bg_color);
+gboolean gdm_common_select_time_format	(void);
+void	setup_background_color		(gchar *bg_color);
+gchar*	gdm_get_welcomemsg		(void);
 
 #endif /* GDM_COMMON_H */
