@@ -1,3 +1,21 @@
+/* GDM - The GNOME Display Manager
+ * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #include "config.h"
 
 #include <gtk/gtk.h>
@@ -7,11 +25,9 @@
 #include <gdk/gdkx.h>
 #include <X11/XKBlib.h>
 
-#include "vicious.h"
 #include "greeter_parser.h"
 #include "greeter_item_capslock.h"
 
-
 static gboolean caps_lock_state = FALSE;
 
 static Display *
@@ -30,14 +46,14 @@ get_parent_display (void)
       char *old_xauth = g_strdup (g_getenv ("XAUTHORITY"));
       if (g_getenv ("GDM_PARENT_XAUTHORITY") != NULL)
         {
-	  ve_setenv ("XAUTHORITY",
-		     g_getenv ("GDM_PARENT_XAUTHORITY"), TRUE);
+	  g_setenv ("XAUTHORITY",
+		    g_getenv ("GDM_PARENT_XAUTHORITY"), TRUE);
 	}
       dsp = XOpenDisplay (g_getenv ("GDM_PARENT_DISPLAY"));
       if (old_xauth != NULL)
-        ve_setenv ("XAUTHORITY", old_xauth, TRUE);
+        g_setenv ("XAUTHORITY", old_xauth, TRUE);
       else
-        ve_unsetenv ("XAUTHORITY");
+        g_unsetenv ("XAUTHORITY");
       g_free (old_xauth);
     }
 
@@ -47,7 +63,7 @@ get_parent_display (void)
 gboolean
 greeter_is_capslock_on (void)
 {
-  unsigned int states;
+  XkbStateRec states;
   Display *dsp;
 
   /* HACK! incredible hack, if this is set we get
@@ -57,10 +73,10 @@ greeter_is_capslock_on (void)
   if (dsp == NULL)
     dsp = GDK_DISPLAY ();
 
-  if (XkbGetIndicatorState (dsp, XkbUseCoreKbd, &states) != Success)
+  if (XkbGetState (dsp, XkbUseCoreKbd, &states) != Success)
       return FALSE;
 
-  return (states & ShiftMask) != 0;
+  return (states.locked_mods & LockMask) != 0;
 }
 
 
