@@ -25,6 +25,7 @@
 /* For clist */
 #undef GTK_DISABLE_DEPRECATED
 
+#include <stdlib.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 
@@ -398,7 +399,7 @@ glade_helper_tagify_label (GladeXML *xml,
 					    GTK_TYPE_LABEL);
 		exit (1);
 	}
-	lbl = gtk_label_get_text (GTK_LABEL (label));
+	lbl = gtk_label_get_label (GTK_LABEL (label));
 	s = g_strdup_printf ("<%s>%s</%s>", tag, lbl, tag);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	gtk_label_set_label (GTK_LABEL (label), s);
