@@ -24,8 +24,11 @@
 #include <stdlib.h>
 #include <locale.h>
 
-#include "ve-i18n.h"
+#ifdef HAVE_CRT_EXTERNS_H
+#include <crt_externs.h>
+#endif
 
+#include "ve-i18n.h"
 #include "ve-misc.h"
 
 char **
@@ -400,7 +403,12 @@ ve_unsetenv (const char *name)
 #if defined (HAVE_SETENV)
 	unsetenv (name);
 #else
-	extern char **environ;
+
+#ifdef HAVE__NSGETENVIRON
+#define environ (*_NSGetEnviron())
+#else
+        extern char **environ;
+#endif
 	int i, len;
 
 	if (environ == NULL)
@@ -440,7 +448,13 @@ ve_clearenv (void)
 #ifdef HAVE_CLEARENV
 	clearenv ();
 #else
-	extern char **environ;
+
+#ifdef HAVE__NSGETENVIRON
+#define environ (*_NSGetEnviron())
+#else
+        extern char **environ;
+#endif
+
 	if (environ != NULL)
 		environ[0] = NULL;
 #endif
